package org.qatools.util;

import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;


public class ListUtil extends QAToolsUtil {
    private static long cUniqueLong = System.currentTimeMillis();
    private static String DAFAULT_DELIM = ",";
    
    
	// -------------------------------------------------------------
	// ----- isListNullOrEmpty -------------------------------------
	// -------------------------------------------------------------

    public static <T extends Object> boolean isListNullOrEmpty(List<T> list) {
    	if (list==null || list.size()==0) {
    		return true;
    	}
    	return false;
    }

	// -------------------------------------------------------------
	// ----- isArrayNullOrEmpty ------------------------------------
	// -------------------------------------------------------------

    public static <T extends Object> boolean isArrayNullOrEmpty(T[] arr) {
    	if (arr==null || arr.length==0) {
    		return true;
    	}
    	return false;
    }

    // --------------------------------------------------------------------
    // ----- 
    // --------------------------------------------------------------------

    /**
     * 
     * @param list
     * @return
     */
    public static <T extends Object> String getDelimitedStr(List<T> list, String delim) {
    	if (list==null || list.size()==0) {
    		return null;
    	}
    	
    	if (delim==null || delim.length()==0) {
    		delim = DAFAULT_DELIM;
    	}
    	
    	String s = "";
    	String d = "";
    	for (T t : list) {
    		s += d + t.toString();
    		d = delim;
    	}
    	return s;
    }
    
    /**
     * 
     * @param list
     * @param delim
     * @return
     */
    public static <T extends Object> String getCommaDelimitedStr(List<T> list) {
    	return getDelimitedStr(list, ",");
    }

    /**
     * 
     * @param list
     * @param delim
     * @return
     */
    public static <T extends Object> String getPipeDelimitedStr(List<T> list) {
    	return getDelimitedStr(list, "|");
    }

    /**
     * 
     * @param list
     * @param delim
     * @return
     */
    public static <T extends Object> String getSpaceDelimitedStr(List<T> list) {
    	return getDelimitedStr(list, " ");
    }

    // --------------------------------------------------------------------
    // ----- 
    // --------------------------------------------------------------------

    /**
     * Retunrs a quoted comma delimited string
     * 	{1 2 3} returns '1','2','3'
     * 
     * Good for query generations
     * select foo from bar where id in (ListUtil.getQuotedCommaDelimitedStr())
     * 
     * @param list
     * @return
     */
    public static <T extends Object> String getQuotedCommaDelimitedStr(List<T> list) {
    	String s = getDelimitedStr(list,"','");
    	if (s==null || s.length()==0) {
    		return null;
    	}
    	return "'" + s + "'";
    }

    // --------------------------------------------------------------------
    // ----- 
    // --------------------------------------------------------------------

    /**
     * 
     * @param list
     * @return
     */
    public static <T extends Object> List<T> removeDups(List<T> list) {
        if (list==null || list.size()==0) {
        	return null;
        }
        
        // remove duplicates
        HashSet<T> hashSet = new HashSet<T>(list);

        // unique list
        List<T> list2 = new LinkedList<T>(hashSet);
 
        if (list2==null || list2.size()==0) {
        	return null;
        }
 
       	return list2;
    }



    
}